Removed most ancient references to Beagle in the code, replaced by WebQueue or such to clarify things. No real changes

Jean-Francois Dockes Jean-Francois Dockes 2018-05-31

changed src/common/webstore.cpp
changed src/common/webstore.h
changed src/index/fetcher.cpp
changed src/index/indexer.cpp
changed src/index/indexer.h
changed src/index/recollindex.cpp
changed src/index/webqueue.cpp
changed src/index/webqueue.h
changed src/qtgui/webcache.cpp
changed src/Makefile.am
copied src/index/bglfetcher.cpp -> src/index/webqueuefetcher.cpp
copied src/index/bglfetcher.h -> src/index/webqueuefetcher.h
src/common/webstore.cpp Diff Switch to side-by-side view
Loading...
src/common/webstore.h Diff Switch to side-by-side view
Loading...
src/index/fetcher.cpp Diff Switch to side-by-side view
Loading...
src/index/indexer.cpp Diff Switch to side-by-side view
Loading...
src/index/indexer.h Diff Switch to side-by-side view
Loading...
src/index/recollindex.cpp Diff Switch to side-by-side view
Loading...
src/index/webqueue.cpp Diff Switch to side-by-side view
Loading...
src/index/webqueue.h Diff Switch to side-by-side view
Loading...
src/qtgui/webcache.cpp Diff Switch to side-by-side view
Loading...
src/Makefile.am Diff Switch to side-by-side view
Loading...
src/index/bglfetcher.cpp to src/index/webqueuefetcher.cpp
--- a/src/index/bglfetcher.h
+++ b/src/index/webqueuefetcher.h
@@ -14,18 +14,19 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#ifndef _BGLFETCHER_H_INCLUDED_
-#define _BGLFETCHER_H_INCLUDED_
+#ifndef _WEBQUEUEFETCHER_H_INCLUDED_
+#define _WEBQUEUEFETCHER_H_INCLUDED_
+
 #include "fetcher.h"
 
 /** 
- * The Beagle cache fetcher: 
+ * The WEB queue cache fetcher: 
  */
-class BGLDocFetcher : public DocFetcher{
+class WQDocFetcher : public DocFetcher{
     virtual bool fetch(RclConfig* cnf, const Rcl::Doc& idoc, RawDoc& out);
     virtual bool makesig(RclConfig* cnf, const Rcl::Doc& idoc,
                          std::string& sig);
-    virtual ~BGLDocFetcher() {}
+    virtual ~WQDocFetcher() {}
 };
 
-#endif /* _BGLFETCHER_H_INCLUDED_ */
+#endif /* _WEBQUEUEFETCHER_H_INCLUDED_ */
--- a/src/index/bglfetcher.cpp
+++ b/src/index/webqueuefetcher.cpp
@@ -16,23 +16,26 @@
  */
 #include "autoconfig.h"
 
+#include "webqueuefetcher.h"
+
 #include <mutex>
 
 #include "rcldoc.h"
 #include "fetcher.h"
-#include "bglfetcher.h"
 #include "log.h"
-#include "beaglequeuecache.h"
+#include "webstore.h"
 
-// We use a single beagle cache object to access beagle data. We protect it 
+using std::string;
+
+// We use a single WebStore object to access the data. We protect it
 // against multiple thread access.
 static std::mutex o_beagler_mutex;
 
-bool BGLDocFetcher::fetch(RclConfig* cnf, const Rcl::Doc& idoc, RawDoc& out)
+bool WQDocFetcher::fetch(RclConfig* cnf, const Rcl::Doc& idoc, RawDoc& out)
 {
     string udi;
     if (!idoc.getmeta(Rcl::Doc::keyudi, &udi) || udi.empty()) {
-	LOGERR("BGLDocFetcher:: no udi in idoc\n" );
+	LOGERR("WQDocFetcher:: no udi in idoc\n" );
 	return false;
     }
     Rcl::Doc dotdoc;
@@ -41,24 +44,23 @@
 	// Retrieve from our webcache (beagle data). The beagler
 	// object is created at the first call of this routine and
 	// deleted when the program exits.
-	static BeagleQueueCache o_beagler(cnf);
+	static WebStore o_beagler(cnf);
 	if (!o_beagler.getFromCache(udi, dotdoc, out.data)) {
-	    LOGINFO("BGLDocFetcher::fetch: failed for ["  << (udi) << "]\n" );
+	    LOGINFO("WQDocFetcher::fetch: failed for [" << udi << "]\n");
 	    return false;
 	}
     }
     if (dotdoc.mimetype.compare(idoc.mimetype)) {
-	LOGINFO("BGLDocFetcher:: udi ["  << (udi) << "], mimetp mismatch: in: ["  << (idoc.mimetype) << "], bgl ["  << (dotdoc.mimetype) << "]\n" );
+	LOGINFO("WQDocFetcher:: udi [" << udi << "], mimetp mismatch: in: [" <<
+                idoc.mimetype << "], bgl [" << dotdoc.mimetype << "]\n");
     }
     out.kind = RawDoc::RDK_DATA;
     return true;
 }
     
-bool BGLDocFetcher::makesig(RclConfig* cnf, const Rcl::Doc& idoc, string& sig)
+bool WQDocFetcher::makesig(RclConfig* cnf, const Rcl::Doc& idoc, string& sig)
 {
     // Bgl sigs are empty
     sig.clear();
     return true;
 }
-
-
@@ -41,24 +44,23 @@
 {
-    // Bgl sigs are empty
+    // Web queue sigs are empty
     sig.clear();
     return true;
src/index/bglfetcher.h to src/index/webqueuefetcher.h